# Product Models

Classes for representing products, product groups, shopping list items, and related data.

## Product

The main product class, initialized from various API response types.

::: grocy.data_models.product.Product
    options:
      members_order: source

## ProductBarcode

::: grocy.data_models.product.ProductBarcode
    options:
      members_order: source

## QuantityUnit

::: grocy.data_models.product.QuantityUnit
    options:
      members_order: source

## Group

Represents a product group.

::: grocy.data_models.product.Group
    options:
      members_order: source

## ShoppingListProduct

A product entry on a shopping list.

::: grocy.data_models.product.ShoppingListProduct
    options:
      members_order: source
